@@ -1,6 +1,6 @@
 '''cr_desktop.py: click desktop checks'''
 #
-# Copyright (C) 2013-2014 Canonical Ltd.
+# Copyright (C) 2013-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 from __future__ import print_function
 
-from clickreviews.cr_common import ClickReview, error, open_file_read, msg
+from clickreviews.cr_common import ClickReview, error, open_file_read
 import glob
 import json
 import os
@@ -28,14 +28,15 @@ from xdg.Exceptions import ParsingError as xdgParsingError
 
 class ClickReviewDesktop(ClickReview):
     '''This class represents click lint reviews'''
-    def __init__(self, fn):
+    def __init__(self, fn, overrides=None):
         peer_hooks = dict()
         my_hook = 'desktop'
         peer_hooks[my_hook] = dict()
         peer_hooks[my_hook]['allowed'] = ClickReview.app_allowed_peer_hooks
         peer_hooks[my_hook]['required'] = ["apparmor"]
 
-        ClickReview.__init__(self, fn, "desktop", peer_hooks=peer_hooks)
+        ClickReview.__init__(self, fn, "desktop", peer_hooks=peer_hooks,
+                             overrides=overrides)
 
         self.desktop_files = dict()  # click-show-files and a couple tests
         self.desktop_entries = dict()
@@ -318,15 +319,20 @@ class ClickReviewDesktop(ClickReview):
             found_named_webapp = False
             urls = []
             for i in de.getExec().split():
+                if i == "webbrowser-app" or i == "webapp-container":
+                    continue
                 if i.startswith('--webappUrlPatterns'):
                     found_url_patterns = True
                 if i.startswith('--webappModelSearchPath'):
                     found_model_search_path = True
                 if i.startswith('--webapp='):
                     found_model_search_path = True
-                if not i.startswith('--'):
+                # consider potential Exec field codes as 'non urls'
+                if not i.startswith('--') and not i.startswith('%'):
                     urls.append(i)
             is_launching_local_app = True
+            if len(urls) == 0:
+                is_launching_local_app = False
             for url in urls:
                 parts = urlsplit(url)
                 if parts.scheme in ['http', 'https']:
