@@ -19,6 +19,7 @@ from __future__ import print_function
 from clickreviews.cr_common import ClickReview, error, open_file_read
 import yaml
 import os
+import re
 
 
 class ClickReviewSystemd(ClickReview):
@@ -41,7 +42,8 @@ class ClickReviewSystemd(ClickReview):
         # - stop-timeout
         # - TODO: caps
         self.required_keys = ['start', 'description']
-        self.optional_keys = ['stop', 'poststop', 'stop-timeout']
+        self.optional_keys = ['stop', 'poststop', 'stop-timeout'] + \
+            self.snappy_exe_security
 
         self.systemd_files = dict()  # click-show-files and tests
         self.systemd = dict()
@@ -135,15 +137,25 @@ class ClickReviewSystemd(ClickReview):
         for app in sorted(my_dict):
             f = os.path.basename(self.systemd_files[app])
             for o in self.optional_keys:
+                if o in self.snappy_exe_security:
+                    continue  # checked in cr_security.py
                 found = False
                 t = 'info'
                 n = '%s_optional_key_%s_%s' % (test_str, o, f)
                 s = "OK"
                 if o in my_dict[app]:
-                    if o == 'stop-timeout' and \
-                       not isinstance(my_dict[app][o], int):
-                        t = 'error'
-                        s = "'%s' is not an integer" % o
+                    if o == 'stop-timeout':
+                        if isinstance(my_dict[app][o], int):
+                            found = True
+                        elif not isinstance(my_dict[app][o], str):
+                            t = 'error'
+                            s = "'%s' is not a string or integer" % o
+                        elif not re.search(r'[0-9]+[ms]?$', my_dict[app][o]):
+                            t = 'error'
+                            s = "'%s' is not of form NN[ms] (%s)" % \
+                                (my_dict[app][o], o)
+                        else:
+                            found = True
                     elif not isinstance(my_dict[app][o], str):
                         t = 'error'
                         s = "'%s' is not a string" % o
@@ -298,11 +310,27 @@ class ClickReviewSystemd(ClickReview):
 
             if 'stop-timeout' not in my_dict[app]:
                 s = "OK (skip missing)"
-            elif not isinstance(my_dict[app]['stop-timeout'], int):
+                self._add_result(t, n, s)
+                return
+
+            st = my_dict[app]['stop-timeout']
+
+            if not isinstance(st, int) and not isinstance(st, str):
                 t = 'error'
-                s = 'stop-timeout is not an integer'
-            elif my_dict[app]['stop-timeout'] < 0 or \
-                    my_dict[app]['stop-timeout'] > 60:
+                s = 'stop-timeout is not a string or integer'
+                self._add_result(t, n, s)
+                return
+
+            if isinstance(st, str):
+                if re.search(r'[0-9]+[ms]?$', st):
+                    st = int(st.rstrip(r'[ms]'))
+                else:
+                    t = 'error'
+                    s = "'%s' is not of form NN[ms] (%s)" % (my_dict[app], st)
+                self._add_result(t, n, s)
+                return
+
+            if st < 0 or st > 60:
                 t = 'error'
                 s = "stop-timeout '%d' out of range (0-60)" % \
                     my_dict[app]['stop-timeout']
